@@ -13,6 +13,7 @@ import (
 	"sync"
 	"testing"
 
+	"github.com/bep/golibsass/libsass/libsasserrors"
 	qt "github.com/frankban/quicktest"
 )
 
@@ -72,7 +73,6 @@ func TestTranspiler(t *testing.T) {
 				c.Assert(err, qt.IsNil)
 				c.Assert(result.CSS, qt.Equals, test.expect)
 			}
-
 		})
 
 	}
@@ -85,7 +85,7 @@ func TestError(t *testing.T) {
 	_, err = transpiler.Execute("\n\ndiv { color: $blue; }")
 	c.Assert(err, qt.Not(qt.IsNil))
 
-	lerr := err.(Error)
+	lerr := err.(libsasserrors.Error)
 	c.Assert(lerr.Line, qt.Equals, 3)
 	c.Assert(lerr.Column, qt.Equals, 14)
 	c.Assert(lerr.Message, qt.Equals, `Undefined variable: "$blue".`)
@@ -93,7 +93,6 @@ func TestError(t *testing.T) {
 }
 
 func TestSourceMapSettings(t *testing.T) {
-
 	c := qt.New(t)
 	src := `div { p { color: blue; } }`
 
@@ -131,11 +130,11 @@ func TestIncludePaths(t *testing.T) {
 
 	ioutil.WriteFile(colors, []byte(`
 $moo:       #f442d1 !default;
-`), 0644)
+`), 0o644)
 
 	ioutil.WriteFile(content, []byte(`
 content { color: #ccc; }
-`), 0644)
+`), 0o644)
 
 	c := qt.New(t)
 	src := `
@@ -156,11 +155,9 @@ div { p { color: $moo; } }`
 	result, err := transpiler.Execute(src)
 	c.Assert(err, qt.IsNil)
 	c.Assert(result.CSS, qt.Equals, "content{color:#ccc}div p{color:#f442d1}\n")
-
 }
 
 func TestConcurrentTranspile(t *testing.T) {
-
 	c := qt.New(t)
 
 	importResolver := func(url string, prev string) (string, string, bool) {
@@ -169,7 +166,8 @@ func TestConcurrentTranspile(t *testing.T) {
 
 	transpiler, err := New(Options{
 		OutputStyle:    CompressedStyle,
-		ImportResolver: importResolver})
+		ImportResolver: importResolver,
+	})
 
 	c.Assert(err, qt.IsNil)
 
@@ -215,7 +213,8 @@ func TestImportResolverConcurrent(t *testing.T) {
 			for j := 0; j < 100; j++ {
 				transpiler, err := New(Options{
 					OutputStyle:    CompressedStyle,
-					ImportResolver: createImportResolver(j)})
+					ImportResolver: createImportResolver(j),
+				})
 				c.Check(err, qt.IsNil)
 
 				src := `
@@ -235,7 +234,6 @@ div { p { width: $width; } }`
 		}()
 	}
 	wg.Wait()
-
 }
 
 func BenchmarkTranspile(b *testing.B) {
@@ -274,7 +272,6 @@ func BenchmarkTranspile(b *testing.B) {
 		t.src = sassSample
 		t.expect = sassSampleTranspiled
 		runBench(b, t)
-
 	})
 
 	b.Run("SCSS Parallel", func(b *testing.B) {
@@ -305,9 +302,7 @@ $color: #333;
 
 		t.expect = ".content-navigation{border-color:#333}\n"
 		runBench(b, t)
-
 	})
-
 }
 
 func TestParseOutputStyle(t *testing.T) {
@@ -318,5 +313,4 @@ func TestParseOutputStyle(t *testing.T) {
 	c.Assert(ParseOutputStyle("compressed"), qt.Equals, CompressedStyle)
 	c.Assert(ParseOutputStyle("EXPANDED"), qt.Equals, ExpandedStyle)
 	c.Assert(ParseOutputStyle("foo"), qt.Equals, NestedStyle)
-
 }
